/*
############################################################################
# This program is used to test the basic functions of the SD file system.
# It implements simple versions of the cat, rm, ls, echo, cd, pwd, mkdir and
# rmdir commands plus the <, > and >> file redirection operators.
# The program starts up the file driver and then prompts for a command.
#
# Written by Dave Hein
# Copyright (c) 2011, 2012 Parallax, Inc.
# MIT Licensed
############################################################################
*/

#include <stdio.h>
#include <propeller.h>
#include <sys/sd.h>
#include <errno.h>

extern _Driver _SimpleSerialDriver;
extern _Driver _FileDriver;

_Driver *_driverlist[] =
{
    &_SimpleSerialDriver,
    &_FileDriver,
    NULL
};

int manual_mount(void)
{
    printf("Load and mount SD: ");
    _SD_Params* mountParams = (_SD_Params*)-1;

    static _SD_Params params =
    {
        AttachmentType:
        _SDA_SingleSPI,
        pins:
        {
            SingleSPI:
            {
                MISO: 0,   // The pin attached to the SD card's MISO or DO output
                CLK:  1,   // The pin attached to the SD card's CLK or SCLK input
                MOSI: 2,   // The pin attached to the SD card's MOSI or DI input
                CS:   3    // The pin attached to the SD card's CS input
                        }
        }
    };
    mountParams = &params;

    if (mountParams == (_SD_Params*)-1)
    {
        printf("You must specify the SD paramters in the filetest.c\n");
        return 1;
    }

    int mountErr = dfs_mount(mountParams);
    if (mountErr)
    {
        printf("Mount error:%d\n", mountErr);
        return mountErr;
    }

    printf("done.\n");
    return 0;
}


/* The program starts the file system. */
int main(void)
{
    sleep (1);    
    printf("C SD Test.\n");
    manual_mount();

    char buf[80];
    char abe[] = "Everthing you read on the internet is true. - Abraham Lincoln\n";
    int count;
    int size = strlen(abe)+1;

    printf("Writing to file.\n");
     
    FILE* fp = fopen("abe4.txt", "w");

    if(fp)
    {   
        count = fwrite(abe, 1, size, fp);
        fclose(fp);
    
        printf("Wrote number of elements. %d\n",count);        
        
    }
    else
    {
        printf("Couldn't write the file. Errno: %d \n", errno);
    }

    printf("Opening file. \n");
    fp = fopen("abe4.txt", "r");
    if(fp)
    {
        fread(buf, 1, 80, fp);
        fclose(fp);
        printf(buf);
    }
    else
    {
        printf("Couldn't read the file. Errno: %d \n", errno);
    }
    return 0;
}

/*
+--------------------------------------------------------------------
|  TERMS OF USE: MIT License
+--------------------------------------------------------------------
Permission is hereby granted, free of charge, to any person obtaining
a copy of this software and associated documentation files
(the "Software"), to deal in the Software without restriction,
including without limitation the rights to use, copy, modify, merge,
publish, distribute, sublicense, and/or sell copies of the Software,
and to permit persons to whom the Software is furnished to do so,
subject to the following conditions:

The above copyright notice and this permission notice shall be
included in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+------------------------------------------------------------------
*/
